unit Msimg;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, ExtCtrls;

type
  TMyImage = class(TPanel)
  private
    FPicture: TPicture;
    HPicture: TPicture;
    HighLightState: boolean;
    procedure SetHPicture(Value: TPicture);
    procedure SetFPicture(Value: TPicture);
  protected
    procedure Paint; override;
    procedure MouseDown(Button: TMouseButton;
                        Shift: TShiftState;
                        X, Y: Integer); override;
    procedure MouseMove(Shift: TShiftState;
                        X, Y: Integer); override;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  published
    property PictureHighLight: TPicture read HPicture write SetHPicture;
    property PictureNormal: TPicture read FPicture write SetFPicture;
  end;

procedure Register;

implementation


constructor TMyImage.Create(AOwner: TComponent);
begin
   inherited Create(AOwner);
   HPicture := TPicture.Create;
   FPicture := TPicture.Create;
   HighLightState := false;
end;

destructor TMyImage.Destroy;
begin
   HPicture.Free;
   FPicture.Free;
   inherited Destroy;
end;

procedure TMyImage.SetHPicture(Value: TPicture);
begin
   HPicture.Assign(Value);
   Width := Value.Width;
   Height := Value.Height;
end;

procedure TMyImage.SetFPicture(Value: TPicture);
begin
   FPicture.Assign(Value);
   Width := Value.Width;
   Height := Value.Height;
end;

procedure TMyImage.MouseDown(Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
   HighLightState := false;
   Invalidate;
end;

procedure TMyImage.MouseMove(Shift: TShiftState; X, Y: Integer);
begin
   if not HighLightState then begin
       SetCapture(inherited Handle);
       HighLightState := true;
       Invalidate;
   end
   else if (X<0) or (Y<0) or (X>width) or (Y>Height) then begin
       ReleaseCapture;
       HighLightState := false;
       Invalidate;
   end;
end;

procedure TMyImage.Paint;
begin
   if csDesigning in ComponentState then
   with inherited Canvas do begin
      Pen.Style := psDash;
      Brush.Style := bsClear;
      Rectangle(0, 0, Width, Height);
   end;
   with inherited Canvas do
   if HighLightState then Draw(0, 0, PictureHighLight.Graphic)
                     else Draw(0, 0, PictureNormal.Graphic);
end;

procedure Register;
begin
  RegisterComponents('Samples', [TMyImage]);
end;

end.
